4.2. oncilla.buildTocTree — Oncilla 0.1.0 documentation

# 4.2. oncilla.buildTocTree

buildTocTree.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Builds Sphinx documentation Toc Tree file.

Others:

## 4.2.1. Module Attributes

`oncilla.buildTocTree.` `LOGGER`

`oncilla.buildTocTree.` `FILES_EXTENSION`

`oncilla.buildTocTree.` `TOCTREE_TEMPLATE_BEGIN`

`oncilla.buildTocTree.` `TOCTREE_TEMPLATE_END`

## 4.2.2. Functions

`oncilla.buildTocTree.` `buildTocTree`(title, input, output, contentDirectory)

  Builds Sphinx documentation table of content tree file.

  Parameters: | title (unicode) – Package title. input (unicode) – Input file to convert. output (unicode) – Output file. contentDirectory (unicode) – Directory containing the content to be included in the table of content.
  Returns: | Definition success.
  Return type: | bool

`oncilla.buildTocTree.` `getCommandLineArguments`()

  Retrieves command line arguments.

  Returns: | Namespace.
  Return type: | Namespace

`oncilla.buildTocTree.` `main`()

  Starts the Application.

  Returns: | Definition success.
  Return type: | bool